@@ -1,16 +1,17 @@
 import logging
+
 import numpy as np
 
-from pylops.basicoperators import Diagonal, BlockDiag, Restriction, \
-    HStack
-from pylops.utils.tapers import taper3d
+from pylops.basicoperators import BlockDiag, Diagonal, HStack, Restriction
 from pylops.signalprocessing.Sliding2D import _slidingsteps
+from pylops.utils.tapers import taper3d
 
-logging.basicConfig(format='%(levelname)s: %(message)s', level=logging.WARNING)
+logging.basicConfig(format="%(levelname)s: %(message)s", level=logging.WARNING)
 
 
-def Sliding3D(Op, dims, dimsd, nwin, nover, nop,
-              tapertype='hanning', design=False):
+def Sliding3D(
+    Op, dims, dimsd, nwin, nover, nop, tapertype="hanning", design=False, nproc=1
+):
     """3D Sliding transform operator.
 
     Apply a transform operator ``Op`` repeatedly to patches of the model
@@ -23,7 +24,7 @@ def Sliding3D(Op, dims, dimsd, nwin, nover, nop,
     array in the first and second dimensions (and the entire third dimension).
 
     This operator can be used to perform local, overlapping transforms (e.g.,
-    :obj:`pylops.signalprocessing.FFTN`
+    :obj:`pylops.signalprocessing.FFTND`
     or :obj:`pylops.signalprocessing.Radon3D`) of 3-dimensional arrays.
 
     .. note:: The shape of the model has to be consistent with
@@ -74,17 +75,15 @@ def Sliding3D(Op, dims, dimsd, nwin, nover, nop,
 
     """
     # model windows
-    mwin0_ins, mwin0_ends = _slidingsteps(dims[0],
-                                          Op.shape[1]//(nop[1]*dims[2]), 0)
-    mwin1_ins, mwin1_ends = _slidingsteps(dims[1],
-                                          Op.shape[1]//(nop[0]*dims[2]), 0)
+    mwin0_ins, mwin0_ends = _slidingsteps(dims[0], Op.shape[1] // (nop[1] * dims[2]), 0)
+    mwin1_ins, mwin1_ends = _slidingsteps(dims[1], Op.shape[1] // (nop[0] * dims[2]), 0)
 
     # data windows
     dwin0_ins, dwin0_ends = _slidingsteps(dimsd[0], nwin[0], nover[0])
     dwin1_ins, dwin1_ends = _slidingsteps(dimsd[1], nwin[1], nover[1])
     nwins0 = len(dwin0_ins)
     nwins1 = len(dwin1_ins)
-    nwins = nwins0*nwins1
+    nwins = nwins0 * nwins1
 
     # create tapers
     if tapertype is not None:
@@ -92,42 +91,68 @@ def Sliding3D(Op, dims, dimsd, nwin, nover, nop,
 
     # check that identified number of windows agrees with mode size
     if design:
-        logging.warning('(%d,%d) windows required...', nwins0, nwins1)
-        logging.warning('model wins - start0:%s, end0:%s, start1:%s, end1:%s',
-                        str(mwin0_ins), str(mwin0_ends),
-                        str(mwin1_ins), str(mwin1_ends))
-        logging.warning('data wins - start0:%s, end0:%s, start1:%s, end1:%s',
-                        str(dwin0_ins), str(dwin0_ends),
-                        str(dwin1_ins), str(dwin1_ends))
+        logging.warning("(%d,%d) windows required...", nwins0, nwins1)
+        logging.warning(
+            "model wins - start0:%s, end0:%s, start1:%s, end1:%s",
+            str(mwin0_ins),
+            str(mwin0_ends),
+            str(mwin1_ins),
+            str(mwin1_ends),
+        )
+        logging.warning(
+            "data wins - start0:%s, end0:%s, start1:%s, end1:%s",
+            str(dwin0_ins),
+            str(dwin0_ends),
+            str(dwin1_ins),
+            str(dwin1_ends),
+        )
 
-    if nwins*Op.shape[1]//dims[2] != dims[0]*dims[1]:
-        raise ValueError('Model shape (dims=%s) is not consistent with chosen '
-                         'number of windows. Choose dims[0]=%d and '
-                         'dims[1]=%d for the operator to work with '
-                         'estimated number of windows, or create '
-                         'the operator with design=True to find out the'
-                         'optimal number of windows for the current '
-                         'model size...'
-                         % (str(dims), nwins0*Op.shape[1]//(nop[1]*dims[2]),
-                            nwins1 * Op.shape[1]//(nop[0]*dims[2])))
+    if nwins * Op.shape[1] // dims[2] != dims[0] * dims[1]:
+        raise ValueError(
+            "Model shape (dims=%s) is not consistent with chosen "
+            "number of windows. Choose dims[0]=%d and "
+            "dims[1]=%d for the operator to work with "
+            "estimated number of windows, or create "
+            "the operator with design=True to find out the"
+            "optimal number of windows for the current "
+            "model size..."
+            % (
+                str(dims),
+                nwins0 * Op.shape[1] // (nop[1] * dims[2]),
+                nwins1 * Op.shape[1] // (nop[0] * dims[2]),
+            )
+        )
     # transform to apply
     if tapertype is None:
-        OOp = BlockDiag([Op for _ in range(nwins)])
+        OOp = BlockDiag([Op for _ in range(nwins)], nproc=nproc)
     else:
-        OOp = BlockDiag([Diagonal(tap.flatten()) * Op
-                         for _ in range(nwins)])
+        OOp = BlockDiag([Diagonal(tap.ravel()) * Op for _ in range(nwins)], nproc=nproc)
 
-    hstack = HStack([Restriction(dimsd[1] * dimsd[2] * nwin[0],
-                                 range(win_in, win_end),
-                                 dims=(nwin[0], dimsd[1], dimsd[2]),
-                                 dir=1).H
-                     for win_in, win_end in zip(dwin1_ins,
-                                                dwin1_ends)])
+    hstack = HStack(
+        [
+            Restriction(
+                dimsd[1] * dimsd[2] * nwin[0],
+                range(win_in, win_end),
+                dims=(nwin[0], dimsd[1], dimsd[2]),
+                dir=1,
+                dtype=Op.dtype,
+            ).H
+            for win_in, win_end in zip(dwin1_ins, dwin1_ends)
+        ]
+    )
 
-    combining1 = BlockDiag([hstack]*nwins0)
-    combining0 = HStack([Restriction(np.prod(dimsd),
-                                     range(win_in, win_end),
-                                     dims=dimsd, dir=0).H
-                         for win_in, win_end in zip(dwin0_ins, dwin0_ends)])
+    combining1 = BlockDiag([hstack] * nwins0)
+    combining0 = HStack(
+        [
+            Restriction(
+                np.prod(dimsd),
+                range(win_in, win_end),
+                dims=dimsd,
+                dir=0,
+                dtype=Op.dtype,
+            ).H
+            for win_in, win_end in zip(dwin0_ins, dwin0_ends)
+        ]
+    )
     Sop = combining0 * combining1 * OOp
     return Sop
